Rohde & Schwarz CMA180 Instrument Driver RsCma instrument driver.

Supported instruments: CMA180

The package is hosted here: https://pypi.org/project/RsCma/

Documentation: https://RsCma.readthedocs.io/

Examples: https://github.com/Rohde-Schwarz/Examples/

----------------------------------------------------------------------------------

Release Notes:

Latest release notes summary: Update for Firmware 1.7.10

Version 1.7.10.24

- Update for Firmware 1.7.10
- Fixed several misspelled errors

Version 1.5.70.22

- Added documentation on ReadTheDocs

Version 1.5.70.21

- Added new data types for commands accepting numbers or ON/OFF:
- int or bool
- float or bool

Version 1.5.70.0018

- First released version


